@@ -54,7 +54,7 @@ sub import {
   $self->export_to_level(1, @_);
   SDL::Constants->export_to_level(1);
 }
-$VERSION = '2.2.3.1';
+$VERSION = '2.2.4';
 
 print "$VERSION" if (defined($ARGV[0]) && ($ARGV[0] eq '--SDLperl'));
 
@@ -88,6 +88,18 @@ __END__
 
 SDL_perl - Simple DirectMedia Layer for Perl
 
+=head1 DISCLAIMER
+
+First to clarify:
+
+ THIS IS THE LAST RELEASE OF THIS API. 
+
+That said we are actively redesigning the SDL Bindings on the redesign branch here:
+
+ git://github.com/kthakore/SDL_perl.git  
+ 
+The newrelease will B<break backwards compatibility>. We recommend you try the redesign branch to get a head start on any new code you are developing.
+
 =head1 SYNOPSIS
 
   use SDL;
